'use strict';

var _Object$keys = require('babel-runtime/core-js/object/keys')['default'];

var _interopRequireDefault = require('babel-runtime/helpers/interop-require-default')['default'];

Object.defineProperty(exports, '__esModule', {
	value: true
});
exports['default'] = write_stats;

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _mkdirp = require('mkdirp');

var _mkdirp2 = _interopRequireDefault(_mkdirp);

// writes webpack-stats.json file, which contains assets' file paths

function write_stats(stats, options) {
	var _production_ = options.environment === 'production';
	var _development_ = options.environment === 'development';

	var json = stats.toJson();

	options.output_path = this.options.output.publicPath;

	var output = options.output();

	// to see all webpack stats (for debuggin purpose)
	// output.json = json

	// {
	// 	if (_development_)
	// 	{
	// 		// path.resolve doesn't work for Http protocol
	// 		return this.options.output.publicPath + asset_path
	// 	}
	// 	else
	// 	{
	// 		return path.resolve(this.options.output.path, asset_path)
	// 	}
	// }

	// for each chunk name ("main", "common", ...)
	_Object$keys(json.assetsByChunkName).forEach(function (name) {
		// get javascript chunk real file path

		var javascript = get_assets(name, 'js')[0];
		// the second asset is usually a source map

		if (javascript) {
			output.javascript[name] = javascript;
		}

		// get style chunk real file path

		var style = get_assets(name, 'css')[0];
		// the second asset is usually a source map

		if (style) {
			output.styles[name] = style;
		}
	});

	// gets asset paths by name and extension of their chunk
	function get_assets(name) {
		var extension = arguments.length <= 1 || arguments[1] === undefined ? 'js' : arguments[1];

		var chunk = json.assetsByChunkName[name];

		// a chunk could be a string or an array, so make sure it is an array
		if (!Array.isArray(chunk)) {
			chunk = [chunk];
		}

		return chunk
		// filter by extension
		.filter(function (name) {
			return _path2['default'].extname(name) === '.' + extension;
		})
		// adjust the real path (can be http, filesystem)
		.map(function (name) {
			return options.output_path + name;
		});
	}

	// // output stats for all application javascript entry points
	// Object.keys(this.options.entry).forEach(chunk_name =>
	// {
	// 	let entry = this.options.entry[chunk_name]
	// 	if (Array.isArray(entry))
	// 	{
	// 		entry = entry[entry.length - 1]
	// 	}
	//
	// 	output.javascript[entry] = get_assets(chunk_name, 'js')[0]
	// 	// the second asset is usually a source map
	// })

	// // omit node_modules contents and internal webpack modules
	// const modules = json.modules.filter(module =>
	// {
	// 	return module.name.indexOf('.') === 0 && module.name.indexOf('./~/') !== 0
	// 	// return module.name.indexOf('./~/') !== 0 && module.name.indexOf('(webpack)') !== 0
	// })

	// one can supply a custom filter
	var default_filter = function default_filter(asset, regular_expression) {
		return regular_expression.test(asset.name);
	};

	var default_naming = function default_naming(module) {
		return module.name;
	};

	// for each user specified asset type
	options.assets.forEach(function (asset_description) {
		// one can supply his own filter
		var filter = asset_description.filter || default_filter; //.bind(this)
		// one can supply his own parser
		var parser = asset_description.parser; //.bind(this)
		// one can supply his own namer
		var naming = asset_description.naming || default_naming; //.bind(this)

		// parser is required
		if (!asset_description.parser) {
			throw new Error('parser required for assets type "' + asset_description.name + '"');
		}

		// get real paths for all the files from this asset type
		output[asset_description.name] = json.modules
		// take just modules of this asset type
		.filter(function (module) {
			return filter(module, options.regular_expressions[asset_description.name], options);
		}).reduce(function (set, module) {
			var name = naming(module);
			// determine and set the real file path
			set[name] = parser(module, options);
			return set;
		}, {});
	});

	// for debugging purposes
	// console.log(JSON.stringify(output, null, 2))

	// create all the folders in the path if they don't exist
	_mkdirp2['default'].sync(_path2['default'].dirname(options.output_file));

	// write webpack stats file
	_fs2['default'].writeFileSync(options.output_file, JSON.stringify(output));
}

module.exports = exports['default'];
//# sourceMappingURL=write stats.js.map